VirtualKey

Enum VirtualKey 

pub enum VirtualKey {
Show 89 variants A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Num0, Num1, Num2, Num3, Num4, Num5, Num6, Num7, Num8, Num9, ArrowUp, ArrowDown, ArrowLeft, ArrowRight, ShiftLeft, ShiftRight, CtrlLeft, CtrlRight, AltLeft, AltRight, Space, Enter, Escape, Tab, Backspace, Delete, Home, End, PageUp, PageDown, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, MouseLeft, MouseRight, MouseMiddle, MouseButton4, MouseButton5, GamepadA, GamepadB, GamepadX, GamepadY, GamepadLB, GamepadRB, GamepadLT, GamepadRT, GamepadStart, GamepadSelect, GamepadDpadUp, GamepadDpadDown, GamepadDpadLeft, GamepadDpadRight, GamepadLeftStickPress, GamepadRightStickPress,
}
Platform-independent key/button identifiers. Covers keyboard, mouse, and gamepad inputs.

Variants



A



B



C



D



E



F



G



H



I



J



K



L



M



N



O



P



Q



R



S



T



U



V



W



X



Y



Z



Num0



Num1



Num2



Num3



Num4



Num5



Num6



Num7



Num8



Num9



ArrowUp



ArrowDown



ArrowLeft



ArrowRight



ShiftLeft



ShiftRight



CtrlLeft



CtrlRight



AltLeft



AltRight



Space



Enter



Escape



Tab



Backspace



Delete



Home



End



PageUp



PageDown



F1



F2



F3



F4



F5



F6



F7



F8



F9



F10



F11



F12



MouseLeft



MouseRight



MouseMiddle



MouseButton4



MouseButton5



GamepadA



GamepadB



GamepadX



GamepadY



GamepadLB



GamepadRB



GamepadLT



GamepadRT



GamepadStart



GamepadSelect



GamepadDpadUp



GamepadDpadDown



GamepadDpadLeft



GamepadDpadRight



GamepadLeftStickPress



GamepadRightStickPress