pub struct CheckpointBuilder { /* private fields */ }Expand description
Constructs checkpoint snapshots from event streams and state.
Implementations
Sourceimpl CheckpointBuilder
impl CheckpointBuilder
Sourcepub fn new(timeline_id: &str, tick: u64) -> Self
pub fn new(timeline_id: &str, tick: u64) -> Self
Create a builder targeting a specific timeline and tick.
Sourcepub fn compute_event_hash(events: &[CanonEventSnapshot]) -> String
pub fn compute_event_hash(events: &[CanonEventSnapshot]) -> String
Compute the BLAKE3 chain hash over all events up to this checkpoint.
Events are hashed in order by feeding each event’s digest. This produces the same result regardless of how many times it is computed, as long as the input events are in canonical order.
Sourcepub fn compute_state_hash(state: &StateSnapshot) -> Result<String, String>
pub fn compute_state_hash(state: &StateSnapshot) -> Result<String, String>
Compute BLAKE3 hash of the serialized state snapshot.
Sourcepub fn build(
&self,
events: &[CanonEventSnapshot],
state: &StateSnapshot,
) -> Result<CheckpointSnapshot, String>
pub fn build( &self, events: &[CanonEventSnapshot], state: &StateSnapshot, ) -> Result<CheckpointSnapshot, String>
Build a complete checkpoint snapshot.