pub struct PropDefinition {Show 17 fields
pub id: String,
pub name: String,
pub description: String,
pub look_description: Option<String>,
pub glyph: Option<String>,
pub blocking: bool,
pub walkthrough: bool,
pub targetable: bool,
pub interactive: bool,
pub has_secondary_state: bool,
pub default_state: Option<String>,
pub foley_stub_id: Option<String>,
pub bump_messages: Vec<String>,
pub has_inventory: bool,
pub container_capacity: Option<u32>,
pub loot_table: Option<String>,
pub states: HashMap<String, PropStateDef>,
}Expand description
Prop definition. Props are interactive or decorative objects placed on maps.
Fields
id: StringUnique prop identifier within the pack.
name: StringHuman-readable prop name.
description: StringProp description shown on examine.
look_description: Option<String>Extended look description.
glyph: Option<String>Display glyph (single character string or Unicode).
blocking: boolWhether the prop blocks entity movement. Default: false.
walkthrough: boolWhether entities can walk through (overrides blocking for pathing). Default: false.
targetable: boolWhether the prop can be targeted by abilities. Default: false.
interactive: boolWhether the prop responds to interact actions. Default: false.
has_secondary_state: boolWhether the prop has multiple states. Default: false.
default_state: Option<String>Default state name for multi-state props.
foley_stub_id: Option<String>Foley sound stub identifier.
bump_messages: Vec<String>Messages shown when an entity bumps into this prop.
has_inventory: boolWhether this prop has an inventory. Default: false.
container_capacity: Option<u32>Maximum items this container can hold.
loot_table: Option<String>Loot table identifier for container drops.
states: HashMap<String, PropStateDef>State definitions for multi-state props. Key = state name.